FinvuAuthSdk class
Single place where we decide which concrete classes to use. We can swap implementations later without breaking app code.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
host(
) → IFinvuHost - Default host (Pigeon-based)
-
nativeWrapper(
[IFinvuHost? host]) → IFinvuNativeWrapper - Default Native wrapper (uses host)
-
webViewBridge(
[IFinvuHost? host]) → IFinvuWebViewWrapper - Default WebView bridge (uses host)