IFinvuWebViewWrapper class abstract

Constructors

IFinvuWebViewWrapper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanupAll() Future<void>
Cleanup underlying native resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setupWebView({required Environment env, required WebViewController controller}) Future<void>
Registers the JS channel and wires calls -> host. Must be called before (or right after) loadRequest.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited