IFinvuHost class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cleanupAll(
) → Future< void> -
initAuth(
InitConfig cfg) → Future< FinvuAuthResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setEnvironment(
Environment env) → Future< void> -
startAuth(
String phoneNumber) → Future< FinvuAuthResult> -
toString(
) → String -
A string representation of this object.
inherited
-
verifyOtp(
VerifyOtpReq req) → Future< FinvuAuthResult>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited